==> haskell-network-udp-0.0.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-KmalNYkxOUD8XukgNMIr6W
key:                  network-udp-0.0.0-KmalNYkxOUD8XukgNMIr6W
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  e7f64c10e67b8ac955ba9dae4557a54a
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-KmalNYkxOUD8XukgNMIr6W
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.14-69DWx4NDSHY5IIEQp7TBcR
    network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-udp-0.0.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-LLnWyCcUFDV4Qt8MGabJdp
key:                  network-udp-0.0.0-LLnWyCcUFDV4Qt8MGabJdp
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  36b9bdc9ec2dfb95ac495272262bd7ff
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-LLnWyCcUFDV4Qt8MGabJdp
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-7hVuJTzQFAED0zMLQy38xi
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
